You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by gz...@apache.org on 2020/01/23 12:38:16 UTC

[camel] 02/02: Replace md5 and sha1 with sha512 files

This is an automated email from the ASF dual-hosted git repository.

gzurowski pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git

commit 44453bdd6374ac7f36ba2c71123e95e2aac4dceb
Author: Gregor Zurowski <gr...@zurowski.org>
AuthorDate: Thu Jan 23 13:37:55 2020 +0100

    Replace md5 and sha1 with sha512 files
---
 etc/scripts/release-distro.sh | 18 ++++++++++++++----
 1 file changed, 14 insertions(+), 4 deletions(-)

diff --git a/etc/scripts/release-distro.sh b/etc/scripts/release-distro.sh
index 43d9fa3..070c894 100755
--- a/etc/scripts/release-distro.sh
+++ b/etc/scripts/release-distro.sh
@@ -39,11 +39,21 @@ wget -e robots=off --wait 3 --no-check-certificate \
  -r -np "--reject=html,txt" "--follow-tags=" \
  -P "${DOWNLOAD}/${VERSION}" -nH "--cut-dirs=3" "--level=1" "--ignore-length" \
  "https://repository.apache.org/content/repositories/releases/org/apache/camel/apache-camel/${VERSION}/"
+
+DOWNLOAD_LOCATION="${DOWNLOAD}/${VERSION}/org/apache/camel/apache-camel/${VERSION}"
+
 # Remove duplicate signature files
-rm ${DOWNLOAD}/dist/${VERSION}/*.asc.asc
-# Remove the signature check sum files
-rm ${DOWNLOAD}/dist/${VERSION}/*.asc.md5
-rm ${DOWNLOAD}/dist/${VERSION}/*.asc.sha1
+rm "${DOWNLOAD_LOCATION}/"*.asc.asc
+
+# Remove the md5 and sha1 check sum files
+rm "${DOWNLOAD_LOCATION}/"*.md5
+rm "${DOWNLOAD_LOCATION}/"*.sha1
+
+# Create sha512 check sum files
+cd "${DOWNLOAD_LOCATION}"
+for file in *.pom *.tar.gz *.zip; do
+  sha512sum "${file}" > "${file}.sha512"
+done
 
 echo "################################################################################"
 echo "                         RESET GROUP PERMISSIONS                                "